@@ -98,7 +98,7 @@ public class EnvelopesConnector extends BaseConnector<ArrayDataResponseMto> {
         builder.setCharset(Charset.forName("UTF-8"));
         addSessionData(builder);
         builder.addParameter("action", "list");
-        builder.addParameter("columns", "600,611,102,610,603,604,605,606,607,609");
+        builder.addParameter("columns", "600,611,102,610,603,604,605,606,607,609,662");
         builder.addParameter("timezone", "utc");
         builder.setEntity(createEntity());
         return builder.build();
@@ -137,7 +137,8 @@ public class EnvelopesConnector extends BaseConnector<ArrayDataResponseMto> {
         List<MailContact> bcc = MailContactUtil.convert((List<List<String>>) data[7]);
         String subject = (String) data[8];
         Long sentDate = (Long) data[9];
-        return Mail.createEnvelope(id, flags, color, receivedDate, from, to, cc, bcc, subject, sentDate);
+        String teaser = (String) data[10];
+        return Mail.createEnvelope(id, flags, color, receivedDate, from, to, cc, bcc, subject, teaser, sentDate);
     }
 
 }
