@@ -67,6 +67,8 @@ import com.openexchange.mobile.api.facade.auth.SessionData;
 import com.openexchange.mobile.api.facade.configuration.ConfigurationHelper;
 import com.openexchange.mobile.api.facade.configuration.HostConfiguration;
 import com.openexchange.mobile.api.facade.endpoints.requests.AuthenticationRequestBody;
+import com.openexchange.mobile.api.facade.endpoints.requests.LogoutRequestBody;
+import com.openexchange.mobile.api.facade.endpoints.requests.PushRequestBody;
 import com.openexchange.mobile.api.facade.endpoints.responses.AuthenticationResponseBody;
 import com.openexchange.mobile.api.facade.exceptions.ApiFacadeException;
 import com.openexchange.mobile.api.facade.osgi.MultipleAuthenticationServicesHandler;
@@ -84,6 +86,10 @@ import lombok.extern.slf4j.Slf4j;
 @Slf4j
 public class AuthenticationEndpoint {
 
+    private static final String FIELD_TOKEN = "token";
+
+    private static final String FIELD_TRANSPORT = "transport";
+
     private static final Pattern PATTERN_CLIENT_ID = Pattern.compile("^\\p{Alnum}*$");
 
     private final MultipleAuthenticationServicesHandler authenticationHandler;
@@ -126,6 +132,9 @@ public class AuthenticationEndpoint {
         if (StringUtils.isEmpty(password)) {
             throw ApiFacadeException.missingParameter("password");
         }
+        if ("".equals(clientId)) {
+            clientId = null;
+        }
         return new LoginCredentials(username, password, clientId)
                 .withForwardedFor(RequestUtil.getForwardedForWithRemoteIp(request))
                 .withRemoteIp(RequestUtil.getRemoteIp(request));
@@ -135,15 +144,28 @@ public class AuthenticationEndpoint {
     @Path("/logout")
     @Consumes(MediaType.APPLICATION_JSON)
     @Produces(MediaType.APPLICATION_JSON)
-    public Response logout(@Context HttpServletRequest request) {
+    public Response logout(@Context HttpServletRequest request, String rawRequestBody) {
         log.info("Logging out client");
         SessionData sessionData = RequestUtil.getSessionData(request);
         HostConfiguration configuration = sessionData.getConfiguration();
         AuthenticationService authenticationService = authenticationHandler.getAuthenticationService(configuration);
-        authenticationService.logout(sessionData);
+        LogoutRequestBody requestBody = StringUtils.isEmpty(rawRequestBody)
+                ? new LogoutRequestBody(null)
+                : JacksonUtil.parse(rawRequestBody, LogoutRequestBody.class);
+        validateLogoutRequestBody(requestBody);
+        authenticationService.logout(sessionData, requestBody);
         return RequestUtil.emptyJsonResponse();
     }
 
+    private void validateLogoutRequestBody(LogoutRequestBody requestBody) {
+        PushRequestBody pushInfo = requestBody.getPushInfo();
+        if (pushInfo == null) {
+            return;
+        }
+        RequestUtil.checkParam(FIELD_TOKEN, pushInfo.getToken());
+        RequestUtil.checkParam(FIELD_TRANSPORT, pushInfo.getTransport());
+    }
+
     private Response buildResponse(SessionData sessionData) {
         AuthenticationResponseBody responseBody = new AuthenticationResponseBody(sessionData);
         String rawResponseBody = JacksonUtil.toString(responseBody);
