@@ -97,13 +97,11 @@ public class Account {
     public Account(AccountMto accountMto, UserMto userMto, String defaultSendAddress, List<Folder> folders) {
         id = accountMto.getId();
         accountName = accountMto.getAccountName();
-        String personalName = accountMto.getPersonalName();
+        userName = getUserName(accountMto.getPersonalName(), userMto);
         if (userMto != null) {
-            userName = StringUtils.isEmpty(personalName) ? userMto.getDisplayName() : personalName;
             firstName = userMto.getFirstName();
             lastName = userMto.getLastName();
         } else {
-            userName = personalName;
             firstName = null;
             lastName = null;
         }
@@ -129,6 +127,27 @@ public class Account {
         }
     }
 
+    private String getUserName(String personalName, UserMto userMto) {
+        String userName;
+        if (userMto == null) {
+            return personalName;
+        }
+        String firstName = userMto.getFirstName();
+        String lastName = userMto.getLastName();
+        if (firstName != null || lastName != null) {
+            if (firstName == null) {
+                userName = lastName;
+            } else if (lastName == null) {
+                userName = firstName;
+            } else {
+                userName = firstName + " " + lastName;
+            }
+        } else {
+            userName = StringUtils.isEmpty(personalName) ? userMto.getDisplayName() : personalName;
+        }
+        return userName;
+    }
+
     public Account withFolders(List<Folder> folders) {
         this.folders = folders;
         standardFolders = createStandardFolders(folders);
