@@ -151,7 +151,7 @@ public class Mail {
         this.parts = null;
     }
 
-    private Mail(String id, int flags, int color, Long receivedDate, List<MailContact> from, List<MailContact> to, List<MailContact> cc, List<MailContact> bcc, String subject, Long sentDate) {
+    private Mail(String id, int flags, int color, Long receivedDate, List<MailContact> from, List<MailContact> to, List<MailContact> cc, List<MailContact> bcc, String subject, String teaser, Long sentDate) {
         this.id = id;
         this.flags = new MailFlags(flags);
         this.color = nonZero(color);
@@ -163,6 +163,7 @@ public class Mail {
         this.cc = cc;
         this.bcc = bcc;
         this.subject = subject;
+        this.teaser = teaser;
         this.replyTo = null;
         this.messageId = null;
         this.accountName = null;
@@ -210,8 +211,8 @@ public class Mail {
         return new Mail(id, flags, color, receivedDate, level);
     }
 
-    public static Mail createEnvelope(String id, int flags, int color, Long receivedDate, List<MailContact> from, List<MailContact> to, List<MailContact> cc, List<MailContact> bcc, String subject, Long sentDate) {
-        return new Mail(id, flags, color, receivedDate, from, to, cc, bcc, subject, sentDate);
+    public static Mail createEnvelope(String id, int flags, int color, Long receivedDate, List<MailContact> from, List<MailContact> to, List<MailContact> cc, List<MailContact> bcc, String subject, String teaser, Long sentDate) {
+        return new Mail(id, flags, color, receivedDate, from, to, cc, bcc, subject, teaser, sentDate);
     }
 
     public static Mail createMail(MailMto mailMto) {
